@@ -4,11 +4,11 @@ from tkinter import ttk
 from pathlib import Path
 from PIL import Image, ImageTk
 
+import psiutils.text as txt
+
 from .constants import PAD, Pad
 from .widgets import enter_widget, clickable_widget, HAND
 
-import psiutils.text as text
-
 
 class IconButton(ttk.Frame):
     def __init__(
@@ -212,38 +212,42 @@ def enable_buttons(buttons: list[Button], enable: bool = True):
 
 
 icon_buttons = {
-    'build': (text.BUILD, 'build'),
-    'close': (text.CLOSE, 'cancel'),
-    'code': (text.CODE, 'code'),
-    'compare': (text.COMPARE, 'compare'),
-    'config': (text.CONFIG, 'gear'),
-    'copy_docs': (text.COPY, 'copy_docs'),
-    'copy_clipboard': (text.COPY, 'copy_clipboard'),
-    'delete': (text.DELETE, 'delete'),
-    'diff': (text.DIFF, 'diff'),
-    'done': (text.DONE, 'done'),
-    'edit': (text.EDIT, 'edit'),
-    'exit': (text.EXIT, 'cancel'),
-    'new': (text.NEW, 'new'),
-    'next': (text.NEXT, 'next'),
-    'open': (text.OPEN, 'open'),
-    'pause': (text.PAUSE, 'pause'),
-    'preferences': (text.PREFERENCES, 'preferences'),
-    'previous': (text.PREVIOUS, 'previous'),
-    'process': (text.PROCESS, 'process'),
-    'redo': (text.REDO, 'redo'),
-    'refresh': (text.REFRESH, 'refresh'),
-    'rename': (text.RENAME, 'rename'),
-    'report': (text.REPORT, 'report'),
-    'reset': (text.RESET, 'reset'),
-    'run': (text.RUN, 'start'),
-    'save': (text.SAVE, 'save'),
-    'send': (text.SEND, 'send'),
-    'start': (text.START, 'start'),
-    'update': (text.UPDATE, 'update'),
-    'upgrade': (text.UPGRADE, 'upgrade'),
-    'use': (text.USE, 'done'),
-    'windows': (text.WINDOWS, 'windows'),
+    'build': (txt.BUILD, 'build'),
+    'check': (txt.CHECK, 'check'),
+    'clear': (txt.CLEAR, 'clear'),
+    'close': (txt.CLOSE, 'cancel'),
+    'code': (txt.CODE, 'code'),
+    'compare': (txt.COMPARE, 'compare'),
+    'config': (txt.CONFIG, 'gear'),
+    'copy_docs': (txt.COPY, 'copy_docs'),
+    'copy_clipboard': (txt.COPY, 'copy_clipboard'),
+    'delete': (txt.DELETE, 'delete'),
+    'diff': (txt.DIFF, 'diff'),
+    'done': (txt.DONE, 'done'),
+    'edit': (txt.EDIT, 'edit'),
+    'exit': (txt.EXIT, 'cancel'),
+    'new': (txt.NEW, 'new'),
+    'next': (txt.NEXT, 'next'),
+    'open': (txt.OPEN, 'open'),
+    'pause': (txt.PAUSE, 'pause'),
+    'preferences': (txt.PREFERENCES, 'preferences'),
+    'previous': (txt.PREVIOUS, 'previous'),
+    'process': (txt.PROCESS, 'process'),
+    'redo': (txt.REDO, 'redo'),
+    'refresh': (txt.REFRESH, 'refresh'),
+    'rename': (txt.RENAME, 'rename'),
+    'report': (txt.REPORT, 'report'),
+    'reset': (txt.RESET, 'reset'),
+    'revert': (txt.REVERT, 'revert'),
+    'run': (txt.RUN, 'start'),
+    'save': (txt.SAVE, 'save'),
+    'script': (txt.SCRIPT, 'script'),
+    'send': (txt.SEND, 'send'),
+    'start': (txt.START, 'start'),
+    'update': (txt.UPDATE, 'update'),
+    'upgrade': (txt.UPGRADE, 'upgrade'),
+    'use': (txt.USE, 'done'),
+    'windows': (txt.WINDOWS, 'windows'),
 }
 
 
