@@ -12,8 +12,9 @@ class Menu(tk.Menu):
         super().__init__(root)
         self.menu_items = menu_items
         for menu_item in menu_items:
+            menu_item.menu = self
             self.add_command(label=menu_item.text, command=menu_item.command,
-                             underline= menu_item.underline,)
+                             underline=menu_item.underline,)
 
     def enable(self, enable: bool = True) -> None:
         enable_menu_items(self, self.menu_items, enable)
@@ -32,8 +33,10 @@ class MenuItem():
         self.command: object = command
         self.dimmable = dimmable
         self.underline = None
+        self.menu = None
 
         if 'disabled' in kwargs and kwargs['disabled']:
+            self.state = tk.DISABLED
             self.disable()
         if 'underline' in kwargs:
             self.underline = kwargs['underline']
@@ -41,6 +44,12 @@ class MenuItem():
     def __repr__(self) -> str:
         return f'MenuItem: {self.text}'
 
+    def enable(self) -> None:
+        enable_menu_items(self.menu, [self], True)
+
+    def disable(self) -> None:
+        enable_menu_items(self.menu, [self], False)
+
 
 def enable_menu_items(menu: Menu, menu_items: list, enable: bool) -> None:
     state = tk.NORMAL if enable else tk.DISABLED
