@@ -1,5 +1,7 @@
 BUILD = 'Build'
 CANCEL = 'Cancel'
+CHECK = 'Check'
+CLEAR = 'Clear'
 CLOSE = 'Close'
 CODE = 'Code'
 COMPARE = 'Compare'
@@ -29,8 +31,10 @@ REFRESH = 'Refresh'
 REPORT = 'Report'
 RENAME = 'Rename'
 RESET = 'Reset'
+REVERT = 'Revert'
 RUN = 'Run'
 SAVE = 'Save'
+SCRIPT = 'Script'
 SAVE_PDF = 'Save as PDF'
 SEND = 'Send'
 START = 'Start'
